@@ -2,7 +2,7 @@
 from fastapi import Depends, FastAPI
 from gai.lib.server import api_dependencies
 
-def create_app(pyproject_toml, category, gai_config):
+def create_app(pyproject_toml, category, generator_config):
 
     app=FastAPI(
         title="Gai Generators Service",
@@ -14,7 +14,7 @@ def create_app(pyproject_toml, category, gai_config):
 
     # Event Handlers
     from gai.lib.server.api_event_handlers import get_startup_event, get_shutdown_event
-    app.add_event_handler("startup", get_startup_event(app, category=category, pyproject_toml=pyproject_toml, gai_config=gai_config))
+    app.add_event_handler("startup", get_startup_event(app, category=category, pyproject_toml=pyproject_toml, generator_config=generator_config))
     app.add_event_handler("shutdown", get_shutdown_event(app))
 
     return app
