@@ -7,7 +7,8 @@ if not os.environ.get("OPENAI_API_KEY",None):
     os.environ["OPENAI_API_KEY"]=""
 client=OpenAI()
 from gai.ttt.client.completions import Completions
-client=Completions.PatchOpenAI(client)
+from gai.lib.config.config_utils import get_client_config
+client=Completions.PatchOpenAI(client, get_client_config(config_type_or_name="ttt").url)
 
 def chat(content):
     console=Console()
@@ -20,7 +21,7 @@ def chat(content):
             model="exllamav2-mistral7b",
             messages=inner_messages,
             stream=True,
-            max_new_tokens=1000,
+            max_tokens=1000,
             stopping_conditions=[""]
             )
         for chunk in response:
