@@ -14,7 +14,8 @@ if not os.environ.get("OPENAI_API_KEY",None):
     os.environ["OPENAI_API_KEY"]=""
 client=OpenAI()
 from gai.ttt.client.completions import Completions
-client=Completions.PatchOpenAI(client)
+from gai.lib.config.config_utils import get_client_config
+client=Completions.PatchOpenAI(client,get_client_config(config_type_or_name="ttt").url)
 
 def summarize(file_path):
     # Read the file
